'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Create the base template, returning a top and a bottom part
 *
 * @param  {String} dest The URL carte-blanche should be at
 * @return {Object}      The template split into two parts
 */
var createBaseTemplate = function createBaseTemplate(dest) {
  return {
    top: '\n<!DOCTYPE html>\n<html>\n  <head>\n    <meta charset="UTF-8">\n    <title>CarteBlanche</title>\n    <link rel="stylesheet" type="text/css" href="' + (dest ? '/' + _path2.default.join(dest, 'client-bundle.css') : 'client-bundle.css') + '" />\n  </head>\n  <body>\n    <div id=\'carte-blanche-root\'></div>\n',
    bottom: '\n    <script src="' + (dest ? '/' + _path2.default.join(dest, 'client-bundle.js') : 'client-bundle.js') + '"></script>\n    <script src="' + (dest ? '/' + _path2.default.join(dest, 'user-bundle.js') : 'user-bundle.js') + '"></script>\n  </body>\n</html>'
  };
};

/**
 * Create HTML from a base template with injected styles and scripts
 *
 * @param  {Array} scripts An array of strings filled with JS code
 * @param  {Array} styles              --“--               CSS code
 *
 * @return {String}        The finished HTML
 */
/* eslint-disable max-len */
var createHTML = function createHTML(dest, scripts, styles) {
  var baseTemplate = createBaseTemplate(dest || '');
  // If there's no scripts or styles return the basetemplate
  if (!scripts && !styles) {
    return baseTemplate.top + '\n' + baseTemplate.bottom;
  }

  // Put together the injected content
  var injectedContent = '';
  if (scripts) {
    injectedContent += '    <script>' + scripts.join('\n') + '</script>\n';
  }
  if (styles) {
    injectedContent += '    <style>' + styles.join('\n') + '</style>\n';
  }
  return '' + baseTemplate.top + injectedContent + baseTemplate.bottom;
};

exports.default = createHTML;